@@ -314,6 +314,7 @@ def resume(ctx):
     echo("Executing %s..." % ' '.join(cmd))
     subprocess.call(cmd)
 
+
 @job.command(help="View parameters for this job.")
 @option('--raw', 'is_raw', is_flag=True, help='Dump raw json response from endpoint')
 @pass_context
@@ -330,6 +331,7 @@ def params(ctx, is_raw):
             vv = vv[:100] + "..."
         print_tab(k, vv)
 
+
 @job.command(help="View logs associated with a job. Choose the log group to stream.")
 @argument('log_group', default='')
 @option('--filter', 'log_filter', help='Filter logs on text')
@@ -338,7 +340,10 @@ def logs(ctx, log_group, log_filter):
     workflow_job = ctx.obj.job
     if not log_group:
         log_groups = workflow_job.log_groups()
-        echo("The following log groups are available for job %s:\n  %s" % (workflow_job.job_id, "\n  ".join(log_groups.keys())))
+        echo(
+            "The following log groups are available for job %s:\n  %s"
+            % (workflow_job.job_id, "\n  ".join(log_groups.keys()))
+        )
         sys.exit(1)
     try:
         logs = workflow_job.logs(log_group, log_filter)
@@ -481,7 +486,11 @@ def process_pod(ctx, is_raw):
         echo(dumps(pod))
         return
 
-    echo("Showing pod information for pod {} in job {} from when the process was run...".format(process["process_id"], ctx.obj.job.job_id))
+    echo(
+        "Showing pod information for pod {} in job {} from when the process was run...".format(
+            process["process_id"], ctx.obj.job.job_id
+        )
+    )
     keys = [
         'name',
         'namespace',
@@ -505,7 +514,11 @@ def process_node(ctx, is_raw):
     if is_raw:
         echo(dumps(node))
         return
-    echo("Showing node information for pod {} in job {} from when the process was run...".format(process["process_id"], ctx.obj.job.job_id))
+    echo(
+        "Showing node information for pod {} in job {} from when the process was run...".format(
+            process["process_id"], ctx.obj.job.job_id
+        )
+    )
     keys = ['name', 'creation_timestamp', 'labels', 'capacity', 'node_info']
     output_pretty_json(node, keys=keys)
 
@@ -676,10 +689,7 @@ def link(ctx, link_type):
             "&_a=(columns:!(kubernetes.labels.taskName,message),interval:auto,"
             "query:(language:lucene,query:'kubernetes.labels.job-id:{job_id}%20%26%26%20kubernetes.labels.started-by:workflow-service'),"
             "sort:!('@timestamp',desc))".format(
-                kibana_url=kibana_url,
-                start_date=start_date,
-                end_date=end_date,
-                job_id=job_id,
+                kibana_url=kibana_url, start_date=start_date, end_date=end_date, job_id=job_id,
             )
         )
         echo(link)
