@@ -20,6 +20,7 @@ log = logging.getLogger(__name__)
 @argument('project_name', required=False)
 @option('-p', '--parameters', help="Parameters for the run", multiple=True)
 @option('-s', '--script', help="Git link to a workflow (only for custom)")
+@option('-c', '--context', help="Optional context string")
 @option('-r', '--revision', help="Git SHA to run")
 @option('--profile', help="Nextflow configuration profile to use")
 @option('--local', 'local_folder', help='Run a local nextflow folder')
@@ -42,6 +43,7 @@ def run(
     project_name,
     parameters,
     script,
+    context,
     revision,
     profile,
     local_folder,
@@ -71,6 +73,7 @@ def run(
         script = script or manifest.get('script')
         revision = revision or manifest.get('revision')
         profile = profile or manifest.get('profile')
+        context = context or manifest.get('context')
         params = manifest.get('params', {})
     try:
         override_params = {}
@@ -129,6 +132,7 @@ def run(
             build_context,
             profile,
             trace,
+            context=context,
             description=description,
             executor_memory_mb=int(executor_memory_mb) if executor_memory_mb else None,
         )
